@@ -15,11 +15,13 @@ int main(int argc, char** argv)
         .set_presentation_contexts({
             {
                 odil::registry::MRImageStorage,
-                { odil::registry::ImplicitVRLittleEndian }, false, true
+                { odil::registry::ImplicitVRLittleEndian }, 
+                odil::AssociationParameters::PresentationContext::Role::SCP
             },
             {
                 odil::registry::VerificationSOPClass,
-                { odil::registry::ImplicitVRLittleEndian }, true, false
+                { odil::registry::ImplicitVRLittleEndian }, 
+                odil::AssociationParameters::PresentationContext::Role::SCU
             }
         });
     
