@@ -30,42 +30,37 @@ NSetSCU
     // Nothing else.
 }
 
-NSetSCU
-::~NSetSCU()
-{
-    // Nothing to do.
-}
-
 void 
 NSetSCU
-::set_affected_sop_class(DataSet const & dataset)
+::set_affected_sop_class(std::shared_ptr<DataSet const> dataset)
 {
-    auto const & sop_class_uid = dataset.as_string(registry::RequestedSOPClassUID, 0);
+    auto const & sop_class_uid = dataset->as_string(
+        registry::RequestedSOPClassUID, 0);
 
     this->SCU::set_affected_sop_class(sop_class_uid);
 }
 
 void 
 NSetSCU
-::set( DataSet const & dataset) const
+::set(std::shared_ptr<DataSet> dataset) const
 {
-
-    message::NSetRequest const request(
+    auto request = std::make_shared<message::NSetRequest const>(
         this->_association.next_message_id(),
         this->_affected_sop_class,
-        dataset.as_string(registry::RequestedSOPInstanceUID, 0),
+        dataset->as_string(registry::RequestedSOPInstanceUID, 0),
         dataset);
 
     this->_association.send_message(request, this->_affected_sop_class);
     
-    message::NSetResponse const response = this->_association.receive_message();
+    auto response = std::make_shared<message::NSetResponse const>(
+        this->_association.receive_message());
 
-    if(response.get_message_id_being_responded_to() != request.get_message_id())
+    if(response->get_message_id_being_responded_to() != request->get_message_id())
     {
         std::ostringstream message;
         message << "DIMSE: Unexpected Response MsgId: "
-                << response.get_message_id_being_responded_to()
-                << "(expected: " << request.get_message_id() << ")";
+                << response->get_message_id_being_responded_to()
+                << "(expected: " << request->get_message_id() << ")";
         throw Exception(message.str());
     }
 }
