@@ -30,23 +30,17 @@ CEchoResponse
 }
 
 CEchoResponse
-::CEchoResponse(Message const & message)
+::CEchoResponse(std::shared_ptr<Message const> message)
 : Response(message)
 {
-    if(message.get_command_field() != Command::C_ECHO_RSP)
+    if(!message || message->get_command_field() != Command::C_ECHO_RSP)
     {
         throw Exception("Message is not a C-ECHO-RSP");
     }
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
     
     this->set_affected_sop_class_uid(
-        message.get_command_set().as_string(registry::AffectedSOPClassUID, 0));
-}
-
-CEchoResponse
-::~CEchoResponse()
-{
-    // Nothing to do.
+        message->get_command_set()->as_string(registry::AffectedSOPClassUID, 0));
 }
 
 }
