@@ -24,14 +24,14 @@ NSetRequest
     Value::Integer message_id,
     Value::String const & requested_sop_class_uid,
     Value::String const & requested_sop_instance_uid,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet> dataset)
 : Request(message_id)
 {
-    this->set_command_field( ::odil::message::Message::Command::N_SET_RQ);
+    this->set_command_field(Message::Command::N_SET_RQ);
     this->set_requested_sop_class_uid(requested_sop_class_uid);
     this->set_requested_sop_instance_uid(requested_sop_instance_uid);
 
-    if(dataset.empty())
+    if(!dataset || dataset->empty())
     {
         throw Exception("Data set is required");
     }
@@ -39,32 +39,26 @@ NSetRequest
 }
 
 NSetRequest
-::NSetRequest(Message const & message)
+::NSetRequest(std::shared_ptr<Message> message)
 : Request(message)
 {
-    if(message.get_command_field() != Command::N_SET_RQ)
+    if(!message || message->get_command_field() != Command::N_SET_RQ)
     {
         throw Exception("Message is not a N-SET-RQ");
     }
 
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
 
     this->set_requested_sop_class_uid(
-        message.get_command_set().as_string(registry::RequestedSOPClassUID, 0));
+        message->get_command_set()->as_string(registry::RequestedSOPClassUID, 0));
     this->set_requested_sop_instance_uid(
-        message.get_command_set().as_string(registry::RequestedSOPInstanceUID, 0));
+        message->get_command_set()->as_string(registry::RequestedSOPInstanceUID, 0));
 
-    if(!message.has_data_set() || message.get_data_set().empty())
+    if(!message->has_data_set() || message->get_data_set()->empty())
     {
         throw Exception("Data set is required");
     }
-    this->set_data_set(message.get_data_set());
-}
-
-NSetRequest
-::~NSetRequest()
-{
-    // Nothing to do.
+    this->set_data_set(message->get_data_set());
 }
 
 }
