@@ -28,6 +28,7 @@ void update_0008(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0010(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0012(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0014(ElementsDictionary &, std::map<std::string, odil::Tag> &);
+void update_0016(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0018(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0020(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_misc(ElementsDictionary &, std::map<std::string, odil::Tag> &);
@@ -35,6 +36,7 @@ void update_0022(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0024(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0028(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0032(ElementsDictionary &, std::map<std::string, odil::Tag> &);
+void update_0034(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0038(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_003a(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_0040(ElementsDictionary &, std::map<std::string, odil::Tag> &);
@@ -78,6 +80,7 @@ void update_3008(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_300a(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_300c(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_300e(ElementsDictionary &, std::map<std::string, odil::Tag> &);
+void update_3010(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_4000(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_4008(ElementsDictionary &, std::map<std::string, odil::Tag> &);
 void update_4010(ElementsDictionary &, std::map<std::string, odil::Tag> &);
@@ -135,6 +138,9 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.1.2.5", UIDsDictionaryEntry("RLE Lossless", "RLELossless",  "Transfer Syntax"));
     uids_dictionary.emplace("1.2.840.10008.1.2.6.1", UIDsDictionaryEntry("RFC 2557 MIME encapsulation (Retired)", "RFC2557MIMEencapsulation_Retired",  "Transfer Syntax"));
     uids_dictionary.emplace("1.2.840.10008.1.2.6.2", UIDsDictionaryEntry("XML Encoding (Retired)", "XMLEncoding_Retired",  "Transfer Syntax"));
+    uids_dictionary.emplace("1.2.840.10008.1.2.7.1", UIDsDictionaryEntry("SMPTE ST 2110-20 Uncompressed Progressive Active Video", "SMPTEST211020UncompressedProgressiveActiveVideo",  "Transfer Syntax"));
+    uids_dictionary.emplace("1.2.840.10008.1.2.7.2", UIDsDictionaryEntry("SMPTE ST 2110-20 Uncompressed Interlaced Active Video", "SMPTEST211020UncompressedInterlacedActiveVideo",  "Transfer Syntax"));
+    uids_dictionary.emplace("1.2.840.10008.1.2.7.3", UIDsDictionaryEntry("SMPTE ST 2110-30 PCM Digital Audio", "SMPTEST211030PCMDigitalAudio",  "Transfer Syntax"));
     uids_dictionary.emplace("1.2.840.10008.1.3.10", UIDsDictionaryEntry("Media Storage Directory Storage", "MediaStorageDirectoryStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.1.4.1.1", UIDsDictionaryEntry("Talairach Brain Atlas Frame of Reference", "TalairachBrainAtlasFrameofReference",  "Well-known frame of reference"));
     uids_dictionary.emplace("1.2.840.10008.1.4.1.2", UIDsDictionaryEntry("SPM2 T1 Frame of Reference", "SPM2T1FrameofReference",  "Well-known frame of reference"));
@@ -156,6 +162,8 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.1.4.1.18", UIDsDictionaryEntry("SPM2 SINGLESUBJT1 Frame of Reference", "SPM2SINGLESUBJT1FrameofReference",  "Well-known frame of reference"));
     uids_dictionary.emplace("1.2.840.10008.1.4.2.1", UIDsDictionaryEntry("ICBM 452 T1 Frame of Reference", "ICBM452T1FrameofReference",  "Well-known frame of reference"));
     uids_dictionary.emplace("1.2.840.10008.1.4.2.2", UIDsDictionaryEntry("ICBM Single Subject MRI Frame of Reference", "ICBMSingleSubjectMRIFrameofReference",  "Well-known frame of reference"));
+    uids_dictionary.emplace("1.2.840.10008.1.4.3.1", UIDsDictionaryEntry("IEC 61217 Fixed Coordinate System Frame of Reference", "IEC61217FixedCoordinateSystemFrameofReference",  "Well-known frame of reference"));
+    uids_dictionary.emplace("1.2.840.10008.1.4.3.2", UIDsDictionaryEntry("Standard Robotic-Arm Coordinate System Frame of Reference", "StandardRoboticArmCoordinateSystemFrameofReference",  "Well-known frame of reference"));
     uids_dictionary.emplace("1.2.840.10008.1.5.1", UIDsDictionaryEntry("Hot Iron Color Palette SOP Instance", "HotIronColorPaletteSOPInstance",  "Well-known SOP Instance"));
     uids_dictionary.emplace("1.2.840.10008.1.5.2", UIDsDictionaryEntry("PET Color Palette SOP Instance", "PETColorPaletteSOPInstance",  "Well-known SOP Instance"));
     uids_dictionary.emplace("1.2.840.10008.1.5.3", UIDsDictionaryEntry("Hot Metal Blue Color Palette SOP Instance", "HotMetalBlueColorPaletteSOPInstance",  "Well-known SOP Instance"));
@@ -181,6 +189,12 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.2.16.7", UIDsDictionaryEntry("Integrated Taxonomic Information System (ITIS) Taxonomic Serial Number (TSN)", "IntegratedTaxonomicInformationSystemITISTaxonomicSerialNumberTSN",  "Coding Scheme"));
     uids_dictionary.emplace("1.2.840.10008.2.16.8", UIDsDictionaryEntry("Mouse Genome Initiative (MGI)", "MouseGenomeInitiativeMGI",  "Coding Scheme"));
     uids_dictionary.emplace("1.2.840.10008.2.16.9", UIDsDictionaryEntry("PubChem Compound CID", "PubChemCompoundCID",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.10", UIDsDictionaryEntry("ICD-11", "ICD11",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.11", UIDsDictionaryEntry("New York University Melanoma Clinical Cooperative Group", "NewYorkUniversityMelanomaClinicalCooperativeGroup",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.12", UIDsDictionaryEntry("Mayo Clinic Non-radiological Images Specific Body Structure Anatomical Surface Region Guide", "MayoClinicNonradiologicalImagesSpecificBodyStructureAnatomicalSurfaceRegionGuide",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.13", UIDsDictionaryEntry("Image Biomarker Standardisation Initiative", "ImageBiomarkerStandardisationInitiative",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.14", UIDsDictionaryEntry("Radiomics Ontology", "RadiomicsOntology",  "Coding Scheme"));
+    uids_dictionary.emplace("1.2.840.10008.2.16.15", UIDsDictionaryEntry("RadElement", "RadElement",  "Coding Scheme"));
     uids_dictionary.emplace("1.2.840.10008.3.1.1.1", UIDsDictionaryEntry("DICOM Application Context Name", "DICOMApplicationContextName",  "Application Context Name"));
     uids_dictionary.emplace("1.2.840.10008.3.1.2.1.1", UIDsDictionaryEntry("Detached Patient Management SOP Class (Retired)", "DetachedPatientManagementSOPClass_Retired",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.3.1.2.1.4", UIDsDictionaryEntry("Detached Patient Management Meta SOP Class (Retired)", "DetachedPatientManagementMetaSOPClass_Retired",  "Meta SOP Class"));
@@ -349,10 +363,14 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.88.71", UIDsDictionaryEntry("Acquisition Context SR Storage", "AcquisitionContextSRStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.88.72", UIDsDictionaryEntry("Simplified Adult Echo SR Storage", "SimplifiedAdultEchoSRStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.88.73", UIDsDictionaryEntry("Patient Radiation Dose SR Storage", "PatientRadiationDoseSRStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.88.74", UIDsDictionaryEntry("Planned Imaging Agent Administration SR Storage", "PlannedImagingAgentAdministrationSRStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.88.75", UIDsDictionaryEntry("Performed Imaging Agent Administration SR Storage", "PerformedImagingAgentAdministrationSRStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.90.1", UIDsDictionaryEntry("Content Assessment Results Storage", "ContentAssessmentResultsStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.104.1", UIDsDictionaryEntry("Encapsulated PDF Storage", "EncapsulatedPDFStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.104.2", UIDsDictionaryEntry("Encapsulated CDA Storage", "EncapsulatedCDAStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.104.3", UIDsDictionaryEntry("Encapsulated STL Storage", "EncapsulatedSTLStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.104.4", UIDsDictionaryEntry("Encapsulated OBJ Storage", "EncapsulatedOBJStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.104.5", UIDsDictionaryEntry("Encapsulated MTL Storage", "EncapsulatedMTLStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.128", UIDsDictionaryEntry("Positron Emission Tomography Image Storage", "PositronEmissionTomographyImageStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.128.1", UIDsDictionaryEntry("Legacy Converted Enhanced PET Image Storage", "LegacyConvertedEnhancedPETImageStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.129", UIDsDictionaryEntry("Standalone PET Curve Storage (Retired)", "StandalonePETCurveStorage_Retired",  "SOP Class"));
@@ -373,6 +391,12 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.7", UIDsDictionaryEntry("RT Treatment Summary Record Storage", "RTTreatmentSummaryRecordStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.8", UIDsDictionaryEntry("RT Ion Plan Storage", "RTIonPlanStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.9", UIDsDictionaryEntry("RT Ion Beams Treatment Record Storage", "RTIonBeamsTreatmentRecordStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.10", UIDsDictionaryEntry("RT Physician Intent Storage", "RTPhysicianIntentStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.11", UIDsDictionaryEntry("RT Segment Annotation Storage", "RTSegmentAnnotationStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.12", UIDsDictionaryEntry("RT Radiation Set Storage", "RTRadiationSetStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.13", UIDsDictionaryEntry("C-Arm Photon-Electron Radiation Storage", "CArmPhotonElectronRadiationStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.14", UIDsDictionaryEntry("Tomotherapeutic Radiation Storage", "TomotherapeuticRadiationStorage",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.481.15", UIDsDictionaryEntry("Robotic-Arm Radiation Storage", "RoboticArmRadiationStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.501.1", UIDsDictionaryEntry("DICOS CT Image Storage", "DICOSCTImageStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.501.2.1", UIDsDictionaryEntry("DICOS Digital X-Ray Image Storage - For Presentation", "DICOSDigitalXRayImageStorageForPresentation",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.1.1.501.2.2", UIDsDictionaryEntry("DICOS Digital X-Ray Image Storage - For Processing", "DICOSDigitalXRayImageStorageForProcessing",  "SOP Class"));
@@ -418,6 +442,7 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.6.2", UIDsDictionaryEntry("Unified Procedure Step - Watch SOP Class", "UnifiedProcedureStepWatchSOPClass",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.6.3", UIDsDictionaryEntry("Unified Procedure Step - Pull SOP Class", "UnifiedProcedureStepPullSOPClass",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.6.4", UIDsDictionaryEntry("Unified Procedure Step - Event SOP Class", "UnifiedProcedureStepEventSOPClass",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.5.1.4.34.6.5", UIDsDictionaryEntry("Unified Procedure Step - Query SOP Class", "UnifiedProcedureStepQuerySOPClass",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.7", UIDsDictionaryEntry("RT Beams Delivery Instruction Storage", "RTBeamsDeliveryInstructionStorage",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.8", UIDsDictionaryEntry("RT Conventional Machine Verification", "RTConventionalMachineVerification",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.5.1.4.34.9", UIDsDictionaryEntry("RT Ion Machine Verification", "RTIonMachineVerification",  "SOP Class"));
@@ -450,6 +475,10 @@ void update_uids_dictionary(UIDsDictionary & uids_dictionary)
     uids_dictionary.emplace("1.2.840.10008.7.1.1", UIDsDictionaryEntry("Native DICOM Model", "NativeDICOMModel",  "Application Hosting Model"));
     uids_dictionary.emplace("1.2.840.10008.7.1.2", UIDsDictionaryEntry("Abstract Multi-Dimensional Image Model", "AbstractMultiDimensionalImageModel",  "Application Hosting Model"));
     uids_dictionary.emplace("1.2.840.10008.8.1.1", UIDsDictionaryEntry("DICOM Content Mapping Resource", "DICOMContentMappingResource",  "Mapping Resource"));
+    uids_dictionary.emplace("1.2.840.10008.10.1", UIDsDictionaryEntry("Video Endoscopic Image Real-Time Communication", "VideoEndoscopicImageRealTimeCommunication",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.10.2", UIDsDictionaryEntry("Video Photographic Image Real-Time Communication", "VideoPhotographicImageRealTimeCommunication",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.10.3", UIDsDictionaryEntry("Audio Waveform Real-Time Communication", "AudioWaveformRealTimeCommunication",  "SOP Class"));
+    uids_dictionary.emplace("1.2.840.10008.10.4", UIDsDictionaryEntry("Rendition Selection Document Real-Time Communication", "RenditionSelectionDocumentRealTimeCommunication",  "SOP Class"));
     uids_dictionary.emplace("1.2.840.10008.15.0.3.1", UIDsDictionaryEntry("dicomDeviceName", "dicomDeviceName",  "LDAP OID"));
     uids_dictionary.emplace("1.2.840.10008.15.0.3.2", UIDsDictionaryEntry("dicomDescription", "dicomDescription",  "LDAP OID"));
     uids_dictionary.emplace("1.2.840.10008.15.0.3.3", UIDsDictionaryEntry("dicomManufacturer", "dicomManufacturer",  "LDAP OID"));
@@ -504,6 +533,7 @@ bool update(
     update_0010(public_dictionary, public_tags);
     update_0012(public_dictionary, public_tags);
     update_0014(public_dictionary, public_tags);
+    update_0016(public_dictionary, public_tags);
     update_0018(public_dictionary, public_tags);
     update_0020(public_dictionary, public_tags);
     update_misc(public_dictionary, public_tags);
@@ -511,6 +541,7 @@ bool update(
     update_0024(public_dictionary, public_tags);
     update_0028(public_dictionary, public_tags);
     update_0032(public_dictionary, public_tags);
+    update_0034(public_dictionary, public_tags);
     update_0038(public_dictionary, public_tags);
     update_003a(public_dictionary, public_tags);
     update_0040(public_dictionary, public_tags);
@@ -554,6 +585,7 @@ bool update(
     update_300a(public_dictionary, public_tags);
     update_300c(public_dictionary, public_tags);
     update_300e(public_dictionary, public_tags);
+    update_3010(public_dictionary, public_tags);
     update_4000(public_dictionary, public_tags);
     update_4008(public_dictionary, public_tags);
     update_4010(public_dictionary, public_tags);
