@@ -82,6 +82,7 @@ Tag const CassetteID(0x0018, 0x1007);
 Tag const GantryID(0x0018, 0x1008);
 Tag const UniqueDeviceIdentifier(0x0018, 0x1009);
 Tag const UDISequence(0x0018, 0x100a);
+Tag const ManufacturerDeviceClassUID(0x0018, 0x100b);
 Tag const SecondaryCaptureDeviceID(0x0018, 0x1010);
 Tag const HardcopyCreationDeviceID(0x0018, 0x1011);
 Tag const DateOfSecondaryCapture(0x0018, 0x1012);
@@ -249,6 +250,15 @@ Tag const VerticesOfThePolygonalShutter(0x0018, 0x1620);
 Tag const ShutterPresentationValue(0x0018, 0x1622);
 Tag const ShutterOverlayGroup(0x0018, 0x1623);
 Tag const ShutterPresentationColorCIELabValue(0x0018, 0x1624);
+Tag const OutlineShapeType(0x0018, 0x1630);
+Tag const OutlineLeftVerticalEdge(0x0018, 0x1631);
+Tag const OutlineRightVerticalEdge(0x0018, 0x1632);
+Tag const OutlineUpperHorizontalEdge(0x0018, 0x1633);
+Tag const OutlineLowerHorizontalEdge(0x0018, 0x1634);
+Tag const CenterOfCircularOutline(0x0018, 0x1635);
+Tag const DiameterOfCircularOutline(0x0018, 0x1636);
+Tag const NumberOfPolygonalVertices(0x0018, 0x1637);
+Tag const VerticesOfThePolygonalOutline(0x0018, 0x1638);
 Tag const CollimatorShape(0x0018, 0x1700);
 Tag const CollimatorLeftVerticalEdge(0x0018, 0x1702);
 Tag const CollimatorRightVerticalEdge(0x0018, 0x1704);
@@ -602,6 +612,42 @@ Tag const CalciumScoringMassFactorPatient(0x0018, 0x9351);
 Tag const CalciumScoringMassFactorDevice(0x0018, 0x9352);
 Tag const EnergyWeightingFactor(0x0018, 0x9353);
 Tag const CTAdditionalXRaySourceSequence(0x0018, 0x9360);
+Tag const MultienergyCTAcquisition(0x0018, 0x9361);
+Tag const MultienergyCTAcquisitionSequence(0x0018, 0x9362);
+Tag const MultienergyCTProcessingSequence(0x0018, 0x9363);
+Tag const MultienergyCTCharacteristicsSequence(0x0018, 0x9364);
+Tag const MultienergyCTXRaySourceSequence(0x0018, 0x9365);
+Tag const XRaySourceIndex(0x0018, 0x9366);
+Tag const XRaySourceID(0x0018, 0x9367);
+Tag const MultienergySourceTechnique(0x0018, 0x9368);
+Tag const SourceStartDateTime(0x0018, 0x9369);
+Tag const SourceEndDateTime(0x0018, 0x936a);
+Tag const SwitchingPhaseNumber(0x0018, 0x936b);
+Tag const SwitchingPhaseNominalDuration(0x0018, 0x936c);
+Tag const SwitchingPhaseTransitionDuration(0x0018, 0x936d);
+Tag const EffectiveBinEnergy(0x0018, 0x936e);
+Tag const MultienergyCTXRayDetectorSequence(0x0018, 0x936f);
+Tag const XRayDetectorIndex(0x0018, 0x9370);
+Tag const XRayDetectorID(0x0018, 0x9371);
+Tag const MultienergyDetectorType(0x0018, 0x9372);
+Tag const XRayDetectorLabel(0x0018, 0x9373);
+Tag const NominalMaxEnergy(0x0018, 0x9374);
+Tag const NominalMinEnergy(0x0018, 0x9375);
+Tag const ReferencedXRayDetectorIndex(0x0018, 0x9376);
+Tag const ReferencedXRaySourceIndex(0x0018, 0x9377);
+Tag const ReferencedPathIndex(0x0018, 0x9378);
+Tag const MultienergyCTPathSequence(0x0018, 0x9379);
+Tag const MultienergyCTPathIndex(0x0018, 0x937a);
+Tag const MultienergyAcquisitionDescription(0x0018, 0x937b);
+Tag const MonoenergeticEnergyEquivalent(0x0018, 0x937c);
+Tag const MaterialCodeSequence(0x0018, 0x937d);
+Tag const DecompositionMethod(0x0018, 0x937e);
+Tag const DecompositionDescription(0x0018, 0x937f);
+Tag const DecompositionAlgorithmIdentificationSequence(0x0018, 0x9380);
+Tag const DecompositionMaterialSequence(0x0018, 0x9381);
+Tag const MaterialAttenuationSequence(0x0018, 0x9382);
+Tag const PhotonEnergy(0x0018, 0x9383);
+Tag const XRayMassAttenuationCoefficient(0x0018, 0x9384);
 Tag const ProjectionPixelCalibrationSequence(0x0018, 0x9401);
 Tag const DistanceSourceToIsocenter(0x0018, 0x9402);
 Tag const DistanceObjectToTableTop(0x0018, 0x9403);
