@@ -394,6 +394,7 @@ Tag const GeneralAccessoryDescription(0x300a, 0x0422);
 Tag const GeneralAccessoryType(0x300a, 0x0423);
 Tag const GeneralAccessoryNumber(0x300a, 0x0424);
 Tag const SourceToGeneralAccessoryDistance(0x300a, 0x0425);
+Tag const IsocenterToGeneralAccessoryDistance(0x300a, 0x0426);
 Tag const ApplicatorGeometrySequence(0x300a, 0x0431);
 Tag const ApplicatorApertureShape(0x300a, 0x0432);
 Tag const ApplicatorOpening(0x300a, 0x0433);
@@ -420,6 +421,144 @@ Tag const DeliveredNominalRangeModulationFractions(0x300a, 0x0509);
 Tag const DeliveredNominalRangeModulatedRegionDepths(0x300a, 0x0510);
 Tag const DeliveredReferenceDoseDefinition(0x300a, 0x0511);
 Tag const ReferenceDoseDefinition(0x300a, 0x0512);
+Tag const RTControlPointIndex(0x300a, 0x0600);
+Tag const RadiationGenerationModeIndex(0x300a, 0x0601);
+Tag const ReferencedDefinedDeviceIndex(0x300a, 0x0602);
+Tag const RadiationDoseIdentificationIndex(0x300a, 0x0603);
+Tag const NumberOfRTControlPoints(0x300a, 0x0604);
+Tag const ReferencedRadiationGenerationModeIndex(0x300a, 0x0605);
+Tag const TreatmentPositionIndex(0x300a, 0x0606);
+Tag const ReferencedDeviceIndex(0x300a, 0x0607);
+Tag const TreatmentPositionGroupLabel(0x300a, 0x0608);
+Tag const TreatmentPositionGroupUID(0x300a, 0x0609);
+Tag const TreatmentPositionGroupSequence(0x300a, 0x060a);
+Tag const ReferencedTreatmentPositionIndex(0x300a, 0x060b);
+Tag const ReferencedRadiationDoseIdentificationIndex(0x300a, 0x060c);
+Tag const RTAccessoryHolderWaterEquivalentThickness(0x300a, 0x060d);
+Tag const ReferencedRTAccessoryHolderDeviceIndex(0x300a, 0x060e);
+Tag const RTAccessoryHolderSlotExistenceFlag(0x300a, 0x060f);
+Tag const RTAccessoryHolderSlotSequence(0x300a, 0x0610);
+Tag const RTAccessoryHolderSlotID(0x300a, 0x0611);
+Tag const RTAccessoryHolderSlotDistance(0x300a, 0x0612);
+Tag const RTAccessorySlotDistance(0x300a, 0x0613);
+Tag const RTAccessoryHolderDefinitionSequence(0x300a, 0x0614);
+Tag const RTAccessoryDeviceSlotID(0x300a, 0x0615);
+Tag const RTRadiationSequence(0x300a, 0x0616);
+Tag const RadiationDoseSequence(0x300a, 0x0617);
+Tag const RadiationDoseIdentificationSequence(0x300a, 0x0618);
+Tag const RadiationDoseIdentificationLabel(0x300a, 0x0619);
+Tag const ReferenceDoseType(0x300a, 0x061a);
+Tag const PrimaryDoseValueIndicator(0x300a, 0x061b);
+Tag const DoseValuesSequence(0x300a, 0x061c);
+Tag const DoseValuePurpose(0x300a, 0x061d);
+Tag const ReferenceDosePointCoordinates(0x300a, 0x061e);
+Tag const RadiationDoseValuesParametersSequence(0x300a, 0x061f);
+Tag const MetersetToDoseMappingSequence(0x300a, 0x0620);
+Tag const ExpectedInVivoMeasurementValuesSequence(0x300a, 0x0621);
+Tag const ExpectedInVivoMeasurementValueIndex(0x300a, 0x0622);
+Tag const RadiationDoseInVivoMeasurementLabel(0x300a, 0x0623);
+Tag const RadiationDoseCentralAxisDisplacement(0x300a, 0x0624);
+Tag const RadiationDoseValue(0x300a, 0x0625);
+Tag const RadiationDoseSourceToSkinDistance(0x300a, 0x0626);
+Tag const RadiationDoseMeasurementPointCoordinates(0x300a, 0x0627);
+Tag const RadiationDoseSourceToExternalContourDistance(0x300a, 0x0628);
+Tag const RTToleranceSetSequence(0x300a, 0x0629);
+Tag const RTToleranceSetLabel(0x300a, 0x062a);
+Tag const AttributeToleranceValuesSequence(0x300a, 0x062b);
+Tag const ToleranceValue(0x300a, 0x062c);
+Tag const PatientSupportPositionToleranceSequence(0x300a, 0x062d);
+Tag const TreatmentTimeLimit(0x300a, 0x062e);
+Tag const CArmPhotonElectronControlPointSequence(0x300a, 0x062f);
+Tag const ReferencedRTRadiationSequence(0x300a, 0x0630);
+Tag const ReferencedRTInstanceSequence(0x300a, 0x0631);
+Tag const ReferencedRTPatientSetupSequence(0x300a, 0x0632);
+Tag const SourceToPatientSurfaceDistance(0x300a, 0x0634);
+Tag const TreatmentMachineSpecialModeCodeSequence(0x300a, 0x0635);
+Tag const IntendedNumberOfFractions(0x300a, 0x0636);
+Tag const RTRadiationSetIntent(0x300a, 0x0637);
+Tag const RTRadiationPhysicalAndGeometricContentDetailFlag(0x300a, 0x0638);
+Tag const RTRecordFlag(0x300a, 0x0639);
+Tag const TreatmentDeviceIdentificationSequence(0x300a, 0x063a);
+Tag const ReferencedRTPhysicianIntentSequence(0x300a, 0x063b);
+Tag const CumulativeMeterset(0x300a, 0x063c);
+Tag const DeliveryRate(0x300a, 0x063d);
+Tag const DeliveryRateUnitSequence(0x300a, 0x063e);
+Tag const TreatmentPositionSequence(0x300a, 0x063f);
+Tag const RadiationSourceAxisDistance(0x300a, 0x0640);
+Tag const NumberOfRTBeamLimitingDevices(0x300a, 0x0641);
+Tag const RTBeamLimitingDeviceProximalDistance(0x300a, 0x0642);
+Tag const RTBeamLimitingDeviceDistalDistance(0x300a, 0x0643);
+Tag const ParallelRTBeamDelimiterDeviceOrientationLabelCodeSequence(0x300a, 0x0644);
+Tag const BeamModifierOrientationAngle(0x300a, 0x0645);
+Tag const FixedRTBeamDelimiterDeviceSequence(0x300a, 0x0646);
+Tag const ParallelRTBeamDelimiterDeviceSequence(0x300a, 0x0647);
+Tag const NumberOfParallelRTBeamDelimiters(0x300a, 0x0648);
+Tag const ParallelRTBeamDelimiterBoundaries(0x300a, 0x0649);
+Tag const ParallelRTBeamDelimiterPositions(0x300a, 0x064a);
+Tag const RTBeamLimitingDeviceOffset(0x300a, 0x064b);
+Tag const RTBeamDelimiterGeometrySequence(0x300a, 0x064c);
+Tag const RTBeamLimitingDeviceDefinitionSequence(0x300a, 0x064d);
+Tag const ParallelRTBeamDelimiterOpeningMode(0x300a, 0x064e);
+Tag const ParallelRTBeamDelimiterLeafMountingSide(0x300a, 0x064f);
+Tag const PatientSetupUID(0x300a, 0x0650);
+Tag const WedgeDefinitionSequence(0x300a, 0x0651);
+Tag const RadiationBeamWedgeAngle(0x300a, 0x0652);
+Tag const RadiationBeamWedgeThinEdgeDistance(0x300a, 0x0653);
+Tag const RadiationBeamEffectiveWedgeAngle(0x300a, 0x0654);
+Tag const NumberOfWedgePositions(0x300a, 0x0655);
+Tag const RTBeamLimitingDeviceOpeningSequence(0x300a, 0x0656);
+Tag const NumberOfRTBeamLimitingDeviceOpenings(0x300a, 0x0657);
+Tag const RadiationDosimeterUnitSequence(0x300a, 0x0658);
+Tag const RTDeviceDistanceReferenceLocationCodeSequence(0x300a, 0x0659);
+Tag const RadiationDeviceConfigurationAndCommissioningKeySequence(0x300a, 0x065a);
+Tag const PatientSupportPositionParameterSequence(0x300a, 0x065b);
+Tag const PatientSupportPositionSpecificationMethod(0x300a, 0x065c);
+Tag const PatientSupportPositionDeviceParameterSequence(0x300a, 0x065d);
+Tag const DeviceOrderIndex(0x300a, 0x065e);
+Tag const PatientSupportPositionParameterOrderIndex(0x300a, 0x065f);
+Tag const PatientSupportPositionDeviceToleranceSequence(0x300a, 0x0660);
+Tag const PatientSupportPositionToleranceOrderIndex(0x300a, 0x0661);
+Tag const CompensatorDefinitionSequence(0x300a, 0x0662);
+Tag const CompensatorMapOrientation(0x300a, 0x0663);
+Tag const CompensatorProximalThicknessMap(0x300a, 0x0664);
+Tag const CompensatorDistalThicknessMap(0x300a, 0x0665);
+Tag const CompensatorBasePlaneOffset(0x300a, 0x0666);
+Tag const CompensatorShapeFabricationCodeSequence(0x300a, 0x0667);
+Tag const CompensatorShapeSequence(0x300a, 0x0668);
+Tag const RadiationBeamCompensatorMillingToolDiameter(0x300a, 0x0669);
+Tag const BlockDefinitionSequence(0x300a, 0x066a);
+Tag const BlockEdgeData(0x300a, 0x066b);
+Tag const BlockOrientation(0x300a, 0x066c);
+Tag const RadiationBeamBlockThickness(0x300a, 0x066d);
+Tag const RadiationBeamBlockSlabThickness(0x300a, 0x066e);
+Tag const BlockEdgeDataSequence(0x300a, 0x066f);
+Tag const NumberOfRTAccessoryHolders(0x300a, 0x0670);
+Tag const GeneralAccessoryDefinitionSequence(0x300a, 0x0671);
+Tag const NumberOfGeneralAccessories(0x300a, 0x0672);
+Tag const BolusDefinitionSequence(0x300a, 0x0673);
+Tag const NumberOfBoluses(0x300a, 0x0674);
+Tag const EquipmentFrameOfReferenceUID(0x300a, 0x0675);
+Tag const EquipmentFrameOfReferenceDescription(0x300a, 0x0676);
+Tag const EquipmentReferencePointCoordinatesSequence(0x300a, 0x0677);
+Tag const EquipmentReferencePointCodeSequence(0x300a, 0x0678);
+Tag const RTBeamLimitingDeviceAngle(0x300a, 0x0679);
+Tag const SourceRollAngle(0x300a, 0x067a);
+Tag const RadiationGenerationModeSequence(0x300a, 0x067b);
+Tag const RadiationGenerationModeLabel(0x300a, 0x067c);
+Tag const RadiationGenerationModeDescription(0x300a, 0x067d);
+Tag const RadiationGenerationModeMachineCodeSequence(0x300a, 0x067e);
+Tag const RadiationTypeCodeSequence(0x300a, 0x067f);
+Tag const NominalEnergy(0x300a, 0x0680);
+Tag const MinimumNominalEnergy(0x300a, 0x0681);
+Tag const MaximumNominalEnergy(0x300a, 0x0682);
+Tag const RadiationFluenceModifierCodeSequence(0x300a, 0x0683);
+Tag const EnergyUnitCodeSequence(0x300a, 0x0684);
+Tag const NumberOfRadiationGenerationModes(0x300a, 0x0685);
+Tag const PatientSupportDevicesSequence(0x300a, 0x0686);
+Tag const NumberOfPatientSupportDevices(0x300a, 0x0687);
+Tag const RTBeamModifierDefinitionDistance(0x300a, 0x0688);
+Tag const BeamAreaLimitSequence(0x300a, 0x0689);
+Tag const ReferencedRTPrescriptionSequence(0x300a, 0x068a);
 
 }
 
