@@ -10,18 +10,20 @@
 #define _4a178325_e3d6_4f6f_9a18_ba6a983ee396
 
 #include <string>
+
+#include "odil/odil.h"
 #include "odil/Value.h"
 
 namespace odil
 {
 
 /// @brief Convert a string to its UTF-8 representation
-std::string as_utf8(
+ODIL_API std::string as_utf8(
     std::string const & input, Value::Strings const & specific_character_set,
     bool is_pn=false);
 
 /// @brief Convert an UTF-8 string to a specific representation
-std::string as_specific_character_set(
+ODIL_API std::string as_specific_character_set(
     std::string const & input, Value::Strings const & specific_character_set,
     bool is_pn=false);
 
