@@ -16,6 +16,18 @@ BOOST_AUTO_TEST_CASE(PublicDictionary)
     BOOST_REQUIRE_EQUAL(entry.vm, "1");
 }
 
+BOOST_AUTO_TEST_CASE(PublicDictionaryRepeatingGroup)
+{
+    auto const iterator = odil::registry::public_dictionary.find(
+        std::string("60xx0010"));
+    BOOST_REQUIRE(iterator != odil::registry::public_dictionary.end());
+    auto const & entry = iterator->second;
+    BOOST_REQUIRE_EQUAL(entry.name, "Overlay Rows");
+    BOOST_REQUIRE_EQUAL(entry.keyword, "OverlayRows");
+    BOOST_REQUIRE_EQUAL(entry.vr, "US");
+    BOOST_REQUIRE_EQUAL(entry.vm, "1");
+}
+
 BOOST_AUTO_TEST_CASE(UIDsDictionary)
 {
     auto const iterator = odil::registry::uids_dictionary.find(
