@@ -11,6 +11,14 @@ class TestURL(unittest.TestCase):
         self.assertEqual(url.query, "plip=plop")
         self.assertEqual(url.fragment, "here")
 
+    def test_default_arguments(self):
+        url = odil.webservices.URL("http", "foo.com", "/bar", fragment="here")
+        self.assertEqual(url.scheme, "http")
+        self.assertEqual(url.authority, "foo.com")
+        self.assertEqual(url.path, "/bar")
+        self.assertEqual(url.query, "")
+        self.assertEqual(url.fragment, "here")
+
     def test_serialize(self):
         url = odil.webservices.URL("http", "foo.com", "/bar", "plip=plop", "here")
         self.assertEqual(str(url), "http://foo.com/bar?plip=plop#here")
